summaryrefslogtreecommitdiff
path: root/gps.h
diff options
context:
space:
mode:
authorGary E. Miller <gem@rellim.com>2019-04-05 17:30:44 -0700
committerGary E. Miller <gem@rellim.com>2019-04-05 17:30:44 -0700
commit1047ab92040746ab9597ffcf57a2ced4aaffc07f (patch)
treecc742eef14a49cd8d86f5c3dc939fd56737ae810 /gps.h
parent05f38c3d68c5b61efd78086e8fe0bc6dd15fe793 (diff)
downloadgpsd-1047ab92040746ab9597ffcf57a2ced4aaffc07f.tar.gz
gps.h: Add qErr to gps_fix_t.
qErr, aka "sawtooth" correction, is the error in the PPS time.
Diffstat (limited to 'gps.h')
-rw-r--r--gps.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/gps.h b/gps.h
index a844baf3..7ba6e0b9 100644
--- a/gps.h
+++ b/gps.h
@@ -47,7 +47,7 @@ extern "C" {
* Remove epe from gps_data_t, it duplicates gps_fix_t eph
* Added sep (estimated spherical error, 3D)
* Note: Some GPS call eph as epe, others call sep as epe
* Add gps_fix_t datum string
*/
#define GPSD_API_MAJOR_VERSION 8 /* bump on incompatible changes */
#define GPSD_API_MINOR_VERSION 0 /* bump on compatible changes */
@@ -128,6 +128,8 @@ struct gps_fix_t {
double vAcc; /* Velocity Accuracy Estimate, probably SEP */
} ecef;
char datum[40]; /* map datum */
+ /* quantization error adjustment to PPS. aka "sawtooth" correction */
+ long qErr; /* offset in picoseconds (ps) */
};
/*
@@ -47,7 +47,7 @@ extern "C" {
* Added sep (estimated spherical error, 3D)
* Note: Some GPS call eph as epe, others call sep as epe
- * Add gps_fix_t datum string
+ * Add gps_fix_t datum string, and qErr
*/
#define GPSD_API_MAJOR_VERSION 8 /* bump on incompatible changes */